@@ -1,21 +1,22 @@
 # -*- coding: utf-8 -*-
 """Sub class of `Data` to handle interatomic force constants produced by the Quantum ESPRESSO q2r.x code."""
 import numpy
+from qe_tools import CONSTANTS
 
-from qe_tools.constants import bohr_to_ang
 from aiida.orm import SinglefileData
 
 
 class ForceConstantsData(SinglefileData):
     """Class to handle interatomic force constants from the Quantum ESPRESSO q2r.x code."""
 
-    def set_file(self, file):
+    def set_file(self, file, filename=None, **kwargs):
         """Add a file to the node, parse it and set the attributes found.
 
         :param file: absolute path to the file or a filelike object
+        :param filename: specify filename to use (defaults to name of provided file).
         """
-        # pylint: disable=redefined-builtin,arguments-differ
-        super().set_file(file)
+        # pylint: disable=redefined-builtin
+        super().set_file(file, filename, **kwargs)
 
         # Parse the force constants file
         dictionary, _, _ = parse_q2r_force_constants_file(self.get_content().splitlines(), also_force_constants=False)
@@ -137,7 +138,7 @@ def parse_q2r_force_constants_file(lines, also_force_constants=False):
         if len(celldm) != 6:
             warnings.append('Wrong length for celldm')
         if ibrav != 0:
-            warnings.append('ibrav ({}) is not 0; q-points path for phonon dispersion might be wrong'.format(ibrav))
+            warnings.append(f'ibrav ({ibrav}) is not 0; q-points path for phonon dispersion might be wrong')
         if any([item != 0 for item in celldm[1:]]):
             warnings.append('celldm[1:] are not all zero; only celldm[0] will be used')
 
@@ -147,7 +148,9 @@ def parse_q2r_force_constants_file(lines, also_force_constants=False):
 
         # read cell data
         cell = tuple(
-            tuple(float(c) * celldm[0] * bohr_to_ang for c in l.split()) for l in lines[current_line:current_line + 3]
+            tuple(float(c) * celldm[0] * CONSTANTS.bohr_to_ang
+                  for c in l.split())
+            for l in lines[current_line:current_line + 3]
         )
         parsed_data['cell'] = cell
         current_line += 3
@@ -169,7 +172,7 @@ def parse_q2r_force_constants_file(lines, also_force_constants=False):
                 line[0] = atom_type_list[ityp - 1][0]  # string with element name
                 line[1] = atom_type_list[ityp - 1][1]  # element mass in amu_ry
                 # Convert atomic positions (in cartesian) from alat to Angstrom:
-                line[2:] = [pos * celldm[0] * bohr_to_ang for pos in line[2:]]
+                line[2:] = [pos * celldm[0] * CONSTANTS.bohr_to_ang for pos in line[2:]]
             atom_list.append(tuple(line))
             current_line += 1
 
@@ -227,7 +230,7 @@ def parse_q2r_force_constants_file(lines, also_force_constants=False):
                                         force_constants[mi1, mi2, mi3, ji1, ji2, na1, na2] = float(line[3])
                                         current_line += 1
 
-    except (IndexError, ValueError) as exception:
-        raise ValueError(str(exception) + '\nForce constants file could not be parsed (incorrect file format)')
+    except (IndexError, ValueError) as exc:
+        raise ValueError(str(exc) + '\nForce constants file could not be parsed (incorrect file format)') from exc
 
     return parsed_data, force_constants, warnings
