@@ -5,16 +5,16 @@ The function that needs to be called from outside is parse_raw_output_neb(). The
 specific functionalities. The parsing will try to convert whatever it can in some dictionary, which by operative
 decision doesn't have much structure encoded, [the values are simple ]
 """
-from qe_tools.constants import bohr_to_ang
+from qe_tools import CONSTANTS
 
-from aiida_quantumespresso.parsers import QEOutputParsingError, get_parser_info
+from aiida_quantumespresso.parsers import QEOutputParsingError
 from aiida_quantumespresso.parsers.parse_raw import convert_qe_time_to_sec
 
 
-def parse_raw_output_neb(out_file, input_dict, parser_opts=None):
+def parse_raw_output_neb(stdout, input_dict, parser_opts=None):
     """Parses the output of a neb calculation Receives in input the paths to the output file.
 
-    :param out_file: path to neb std output
+    :param stdout: the stdout content as a string
     :param input_dict: dictionary with the neb input parameters
     :param parser_opts: not used
 
@@ -31,40 +31,33 @@ def parse_raw_output_neb(out_file, input_dict, parser_opts=None):
     import copy
 
     job_successful = True
-    parser_info = get_parser_info(parser_info_template='aiida-quantumespresso parser neb.x v{}')
+    parser_warnings = []
 
-    # load NEB output file
-    try:
-        with open(out_file, 'r') as f:
-            out_lines = f.read()
-    except IOError:  # non existing output file -> job crashed
-        raise QEOutputParsingError('Failed to open output file: {}.'.format(out_file))
-
-    if not out_lines:  # there is an output file, but it's empty -> crash
+    if not stdout:  # there is an output file, but it's empty -> crash
         job_successful = False
 
     # check if the job has finished (that doesn't mean without errors)
     finished_run = False
-    for line in out_lines.split('\n')[::-1]:
+    for line in stdout.split('\n')[::-1]:
         if 'JOB DONE' in line:
             finished_run = True
             break
     if not finished_run:  # error if the job has not finished
         warning = 'QE neb run did not reach the end of the execution.'
-        parser_info['parser_warnings'].append(warning)
+        parser_warnings.append(warning)
         job_successful = False
 
     # parse the text output of the neb calculation
     try:
-        out_data, iteration_data, critical_messages = parse_neb_text_output(out_lines, input_dict)
+        out_data, iteration_data, critical_messages = parse_neb_text_output(stdout, input_dict)
     except QEOutputParsingError as exc:
         if not finished_run:  # I try to parse it as much as possible
-            parser_info['parser_warnings'].append('Error while parsing the output file')
+            parser_warnings.append('Error while parsing the output file')
             out_data = {'warnings': []}
             iteration_data = {}
             critical_messages = []
         else:  # if it was finished and I got an error, it's a mistake of the parser
-            raise QEOutputParsingError('Error while parsing NEB text output: {}'.format(exc))
+            raise QEOutputParsingError(f'Error while parsing NEB text output: {exc}')
 
     # I add in the out_data all the last elements of iteration_data values.
     # I leave the possibility to skip some large arrays (None for the time being).
@@ -79,7 +72,7 @@ def parse_raw_output_neb(out_file, input_dict, parser_opts=None):
     if any([x in out_data['warnings'] for x in critical_messages]):
         job_successful = False
 
-    parameter_data = dict(list(out_data.items()) + list(parser_info.items()))
+    parameter_data = dict(list(out_data.items()) + [('parser_warnings', parser_warnings)])
 
     # return various data.
     # parameter data will be mapped in Dict
@@ -148,10 +141,10 @@ def parse_neb_text_output(data, input_dict={}):
     for count, line in enumerate(lines):
         if 'initial path length' in line:
             initial_path_length = float(line.split('=')[1].split('bohr')[0])
-            parsed_data['initial_path_length'] = initial_path_length * bohr_to_ang
+            parsed_data['initial_path_length'] = initial_path_length * CONSTANTS.bohr_to_ang
         elif 'initial inter-image distance' in line:
             initial_image_dist = float(line.split('=')[1].split('bohr')[0])
-            parsed_data['initial_image_dist'] = initial_image_dist * bohr_to_ang
+            parsed_data['initial_image_dist'] = initial_image_dist * CONSTANTS.bohr_to_ang
         elif 'string_method' in line:
             parsed_data['string_method'] = line.split('=')[1].strip()
         elif 'restart_mode' in line:
@@ -235,9 +228,9 @@ def parse_neb_text_output(data, input_dict={}):
                 iteration_data['climbing_image_auto'].append([int(_) for _ in line.split('=')[1].split(',')])
             elif 'path length' in line:
                 path_length = float(line.split('=')[1].split('bohr')[0])
-                iteration_data['path_length'].append(path_length * bohr_to_ang)
+                iteration_data['path_length'].append(path_length * CONSTANTS.bohr_to_ang)
             elif 'inter-image distance' in line:
                 image_dist = float(line.split('=')[1].split('bohr')[0])
-                iteration_data['image_dist'].append(image_dist * bohr_to_ang)
+                iteration_data['image_dist'].append(image_dist * CONSTANTS.bohr_to_ang)
 
     return parsed_data, dict(iteration_data), list(critical_warnings.values())
